@@ -30,8 +30,8 @@ and workspace.
 * The shells runs in a *subprocess* and can therefore be interrupted or killed.
 * *Multiple shells* can be used at the same time, and can be of different
   Python versions (from v2.4 to 3.x, including pypy)
-* Support for using several *GUI toolkits* interactively: PySide, PyQt4,
-  wx, fltk, GTK, Tk.
+* Support for using several *GUI toolkits* interactively:
+  asyncio, PySide, PySide2, PyQt4, PyQt5, wx, fltk, GTK, Tk, Tornado.
 * Run IPython shell or native shell.
 * *Full Unicode support* in both editor and shell.
 * Various handy *tools*, plus the ability to make your own.
@@ -41,10 +41,11 @@ and workspace.
 """
 
 # Set version number
-__version__ = "4.10.0"
+__version__ = "4.10.2"
 
 import os
 import sys
+import ctypes
 import locale
 import traceback
 
@@ -93,6 +94,14 @@ else:
 from pyzo.util import zon as ssdf  # zon is ssdf-light
 from pyzo.util.qt import QtCore, QtGui, QtWidgets
 
+# Enable high-res displays
+try:
+    ctypes.windll.shcore.SetProcessDpiAwareness(True)
+except Exception:
+    pass
+QtWidgets.QApplication.setAttribute(QtCore.Qt.AA_EnableHighDpiScaling, True)
+QtCore.QCoreApplication.setAttribute(QtCore.Qt.AA_UseHighDpiPixmaps, True)
+
 # Import language/translation tools
 from pyzo.util._locale import translate, setLanguage  # noqa
 
@@ -123,6 +132,7 @@ class MyApp(QtWidgets.QApplication):
 if not sys.platform.startswith("darwin"):
     MyApp = QtWidgets.QApplication  # noqa
 
+
 ## Install excepthook
 # In PyQt5 exceptions in Python will cuase an abort
 # http://pyqt.sourceforge.net/Docs/PyQt5/incompatibilities.html
