@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # Copyright (C) 2016, the Pyzo development team
 #
-# Pyzo is distributed under the terms of the (new) BSD License.
+# Pyzo is distributed under the terms of the 2-Clause BSD License.
 # The full license can be found in 'license.txt'.
 
 """ Module editor
@@ -16,22 +16,22 @@ import os, sys
 import re, codecs
 
 from pyzo.util.qt import QtCore, QtGui, QtWidgets
+
 qt = QtGui
 
 from pyzo.codeeditor import Manager
 from pyzo.core.menu import EditorContextMenu
 from pyzo.core.baseTextCtrl import BaseTextCtrl, normalizePath
-from pyzo.core.statusbar import StatusBar
 from pyzo.core.pyzoLogging import print  # noqa
 import pyzo
 
 
 # Set default line ending (if not set)
 if not pyzo.config.settings.defaultLineEndings:
-    if sys.platform.startswith('win'):
-        pyzo.config.settings.defaultLineEndings = 'CRLF'
+    if sys.platform.startswith("win"):
+        pyzo.config.settings.defaultLineEndings = "CRLF"
     else:
-        pyzo.config.settings.defaultLineEndings = 'LF'
+        pyzo.config.settings.defaultLineEndings = "LF"
 
 
 def determineEncoding(bb):
@@ -41,19 +41,19 @@ def determineEncoding(bb):
     """
 
     # Init
-    firstTwoLines = bb.split(b'\n', 2)[:2]
-    encoding = 'UTF-8'
+    firstTwoLines = bb.split(b"\n", 2)[:2]
+    encoding = "UTF-8"
 
     for line in firstTwoLines:
 
         # Try to make line a string
         try:
-            line = line.decode('ASCII').strip()
+            line = line.decode("ASCII").strip()
         except Exception:
             continue
 
         # Has comment?
-        if line and line[0] == '#':
+        if line and line[0] == "#":
 
             # Matches regular expression given in PEP 0263?
             expression = r"coding[:=]\s*([-\w.]+)"
@@ -88,15 +88,16 @@ def determineLineEnding(text):
     c_lin = text.count("\n") - c_win
     # set the appropriate style
     if c_win > c_mac and c_win > c_lin:
-        mode = '\r\n'
+        mode = "\r\n"
     elif c_mac > c_win and c_mac > c_lin:
-        mode = '\r'
+        mode = "\r"
     else:
-        mode = '\n'
+        mode = "\n"
 
     # return
     return mode
 
+
 def determineIndentation(text):
     return determineIndentationAndTrailingWS(text)[0]
 
@@ -120,8 +121,8 @@ def determineIndentationAndTrailingWS(text):
     trailing = 0
 
     lines = text.splitlines()
-    lines.insert(0,"") # so the lines start at 1
-    for i in range( len(lines) ):
+    lines.insert(0, "")  # so the lines start at 1
+    for i in range(len(lines)):
         line = lines[i]
 
         # remove indentation
@@ -133,11 +134,11 @@ def determineIndentationAndTrailingWS(text):
             trailing += 1
 
         line = lineC
-        if line.startswith('#'):
+        if line.startswith("#"):
             continue
         else:
             # remove everything after the #
-            line = line.split("#",1)[0].rstrip()
+            line = line.split("#", 1)[0].rstrip()
         if not line:
             # continue of no line left
             continue
@@ -146,34 +147,35 @@ def determineIndentationAndTrailingWS(text):
         # check the next line (or the one thereafter)
         # and calculate the indentation difference with THIS line.
         if line.endswith(":"):
-            if len(lines) > i+2:
-                line2 = lines[i+1]
+            if len(lines) > i + 2:
+                line2 = lines[i + 1]
                 tmp = line2.lstrip()
                 if not tmp:
-                    line2 = lines[i+2]
+                    line2 = lines[i + 2]
                     tmp = line2.lstrip()
                 if tmp:
-                    ind2 = len(line2)-len(tmp)
+                    ind2 = len(line2) - len(tmp)
                     ind3 = ind2 - indent
                     if line2.startswith("\t"):
                         indents[-1] += 1
-                    elif ind3>0:
-                        if not ind3 in indents:
+                    elif ind3 > 0:
+                        if ind3 not in indents:
                             indents[ind3] = 1
                         indents[ind3] += 1
 
     # find which was the most common tab width.
-    indent, maxvotes = 0,0
+    indent, maxvotes = 0, 0
     for nspaces in indents:
         if indents[nspaces] > maxvotes:
             indent, maxvotes = nspaces, indents[nspaces]
-    #print "found tabwidth %i" % indent
+    # print "found tabwidth %i" % indent
     return indent, trailing
 
 
 # To give each new file a unique name
 newFileCounter = 0
 
+
 def createEditor(parent, filename=None):
     """ Tries to load the file given by the filename and
     if succesful, creates an editor instance to put it in,
@@ -185,7 +187,7 @@ def createEditor(parent, filename=None):
 
         # Increase counter
         global newFileCounter
-        newFileCounter  += 1
+        newFileCounter += 1
 
         # Create editor
         editor = PyzoEditor(parent)
@@ -202,13 +204,13 @@ def createEditor(parent, filename=None):
             raise IOError("File does not exist '%s'." % filename)
 
         # load file (as bytes)
-        with open(filename, 'rb') as f:
+        with open(filename, "rb") as f:
             bb = f.read()
             f.close()
 
         # convert to text, be gentle with files not encoded with utf-8
         encoding = determineEncoding(bb)
-        text = bb.decode(encoding,'replace')
+        text = bb.decode(encoding, "replace")
 
         # process line endings
         lineEndings = determineLineEnding(text)
@@ -229,7 +231,7 @@ def createEditor(parent, filename=None):
         # process indentation and trailing
         indentWidth, trailing = determineIndentationAndTrailingWS(text)
         editor.removeTrailingWS = trailing < 10  # not too much for ugly diffs
-        if indentWidth == -1: #Tabs
+        if indentWidth == -1:  # Tabs
             editor.setIndentWidth(pyzo.config.settings.defaultIndentWidth)
             editor.setIndentUsingSpaces(False)
         elif indentWidth:
@@ -248,40 +250,39 @@ def createEditor(parent, filename=None):
         # todo: rename style -> parser
         editor.setParser(pyzo.config.settings.defaultStyle)
 
-
     # return
     return editor
 
+
 class PyzoEditor(BaseTextCtrl):
 
     # called when dirty changed or filename changed, etc
     somethingChanged = QtCore.Signal()
 
     def __init__(self, parent, **kwds):
-        super().__init__(parent, showLineNumbers = True, **kwds)
+        super().__init__(parent, showLineNumbers=True, **kwds)
 
         # Init filename and name
-        self._filename = ''
-        self._name = '<TMP>'
+        self._filename = ""
+        self._name = "<TMP>"
 
         # View settings
-        #TODO: self.setViewWrapSymbols(view.showWrapSymbols)
+        # TODO: self.setViewWrapSymbols(view.showWrapSymbols)
         self.setShowLineEndings(pyzo.config.view.showLineEndings)
         self.setShowIndentationGuides(pyzo.config.view.showIndentationGuides)
         #
         self.setWrap(bool(pyzo.config.view.wrap))
         self.setHighlightCurrentLine(pyzo.config.view.highlightCurrentLine)
         self.setLongLineIndicatorPosition(pyzo.config.view.edgeColumn)
-        #TODO: self.setFolding( int(view.codeFolding)*5 )
+        # TODO: self.setFolding( int(view.codeFolding)*5 )
         # bracematch is set in baseTextCtrl, since it also applies to shells
         # dito for zoom and tabWidth
 
-
         # Set line endings to default
         self.lineEndings = pyzo.config.settings.defaultLineEndings
 
         # Set encoding to default
-        self.encoding = 'UTF-8'
+        self.encoding = "UTF-8"
 
         # Modification time to test file change
         self._modifyTime = 0
@@ -297,7 +298,9 @@ class PyzoEditor(BaseTextCtrl):
         # Add context menu (the offset is to prevent accidental auto-clicking)
         self._menu = EditorContextMenu(self)
         self.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
-        self.customContextMenuRequested.connect(lambda p: self._menu.popup(self.mapToGlobal(p)+QtCore.QPoint(0,3)))
+        self.customContextMenuRequested.connect(
+            lambda p: self._menu.popup(self.mapToGlobal(p) + QtCore.QPoint(0, 3))
+        )
 
         # Update status bar
         self.cursorPositionChanged.connect(self._updateStatusBar)
@@ -320,22 +323,21 @@ class PyzoEditor(BaseTextCtrl):
         return self._lineEndings
 
     @lineEndings.setter
-    def lineEndings(self,value):
-        if value in ('\r','\n','\r\n'):
+    def lineEndings(self, value):
+        if value in ("\r", "\n", "\r\n"):
             self._lineEndings = value
             return
         try:
-            self._lineEndings = {'CR': '\r', 'LF': '\n', 'CRLF': '\r\n'}[value]
+            self._lineEndings = {"CR": "\r", "LF": "\n", "CRLF": "\r\n"}[value]
         except KeyError:
-            raise ValueError('Invalid line endings style %r' % value)
+            raise ValueError("Invalid line endings style %r" % value)
 
     @property
     def lineEndingsHumanReadable(self):
         """
         Current line-endings style, human readable (e.g. 'CR')
         """
-        return {'\r': 'CR', '\n': 'LF', '\r\n': 'CRLF'}[self.lineEndings]
-
+        return {"\r": "CR", "\n": "LF", "\r\n": "CRLF"}[self.lineEndings]
 
     @property
     def encoding(self):
@@ -343,7 +345,6 @@ class PyzoEditor(BaseTextCtrl):
         """
         return self._encoding
 
-
     @encoding.setter
     def encoding(self, value):
         # Test given value, correct name if it exists
@@ -351,21 +352,18 @@ class PyzoEditor(BaseTextCtrl):
             c = codecs.lookup(value)
             value = c.name
         except Exception:
-            value = codecs.lookup('UTF-8').name
+            value = codecs.lookup("UTF-8").name
         # Store
         self._encoding = value
 
-
     ##
 
-
     def justifyText(self):
         """ Overloaded version of justifyText to make it use our
         configurable justificationwidth.
         """
         super().justifyText(pyzo.config.settings.justificationWidth)
 
-
     def showRunCursor(self, cursor):
         """
         Momentarily highlight a piece of code to show that this is being executed
@@ -378,7 +376,6 @@ class PyzoEditor(BaseTextCtrl):
 
         self._showRunCursorTimer.singleShot(200, lambda: self.setExtraSelections([]))
 
-
     def id(self):
         """ Get an id of this editor. This is the filename,
         or for tmp files, the name. """
@@ -387,7 +384,6 @@ class PyzoEditor(BaseTextCtrl):
         else:
             return self._name
 
-
     def focusInEvent(self, event):
         """ Test whether the file has been changed 'behind our back'
         """
@@ -396,7 +392,6 @@ class PyzoEditor(BaseTextCtrl):
         # Test file change
         self.testWhetherFileWasChanged()
 
-
     def testWhetherFileWasChanged(self):
         """ testWhetherFileWasChanged()
         Test to see whether the file was changed outside our backs,
@@ -416,12 +411,13 @@ class PyzoEditor(BaseTextCtrl):
 
             # ask user
             dlg = QtWidgets.QMessageBox(self)
-            dlg.setWindowTitle('File was changed')
-            dlg.setText("File has been modified outside of the editor:\n"+
-                        self._filename)
+            dlg.setWindowTitle("File was changed")
+            dlg.setText(
+                "File has been modified outside of the editor:\n" + self._filename
+            )
             dlg.setInformativeText("Do you want to reload?")
-            t=dlg.addButton("Reload", QtWidgets.QMessageBox.AcceptRole) #0
-            dlg.addButton("Keep this version", QtWidgets.QMessageBox.RejectRole) #1
+            t = dlg.addButton("Reload", QtWidgets.QMessageBox.AcceptRole)  # 0
+            dlg.addButton("Keep this version", QtWidgets.QMessageBox.RejectRole)  # 1
             dlg.setDefaultButton(t)
 
             # whatever the result, we will reset the modified time
@@ -432,12 +428,12 @@ class PyzoEditor(BaseTextCtrl):
             if result == QtWidgets.QMessageBox.AcceptRole:
                 self.reload()
             else:
-                pass # when cancelled or explicitly said, do nothing
+                pass  # when cancelled or explicitly said, do nothing
 
             # Return that indeed the file was changes
             return True
 
-    def _onModificationChanged(self,changed):
+    def _onModificationChanged(self, changed):
         """Handler for the modificationChanged signal. Emit somethingChanged
         for the editorStack to update the modification notice."""
         self.somethingChanged.emit()
@@ -461,7 +457,6 @@ class PyzoEditor(BaseTextCtrl):
         else:
             BaseTextCtrl.dropEvent(self, event)
 
-
     def dropEvent(self, event):
         """ Drop files in the list. """
         if event.mimeData().hasUrls():
@@ -471,7 +466,6 @@ class PyzoEditor(BaseTextCtrl):
             # text: act normal
             BaseTextCtrl.dropEvent(self, event)
 
-
     def showEvent(self, event=None):
         """ Capture show event to change title. """
         # Act normally
@@ -481,7 +475,6 @@ class PyzoEditor(BaseTextCtrl):
         # Make parser update
         pyzo.parser.parseThis(self)
 
-
     def setTitleInMainWindow(self):
         """ set the title  text in the main window to show filename. """
 
@@ -492,7 +485,6 @@ class PyzoEditor(BaseTextCtrl):
         else:
             pyzo.main.setMainTitle(name)
 
-
     def save(self, filename=None):
         """ Save the file. No checking is done. """
 
@@ -507,7 +499,10 @@ class PyzoEditor(BaseTextCtrl):
             return
 
         # Remove whitespace in a single undo-able action
-        if self.removeTrailingWS or pyzo.config.settings.removeTrailingWhitespaceWhenSaving:
+        if (
+            self.removeTrailingWS
+            or pyzo.config.settings.removeTrailingWhitespaceWhenSaving
+        ):
             # Original cursor to put state back at the end
             oricursor = self.textCursor()
             # Screen cursor to select document
@@ -521,10 +516,14 @@ class PyzoEditor(BaseTextCtrl):
             try:
                 editCursor.setPosition(screenCursor.selectionStart())
                 editCursor.movePosition(editCursor.StartOfBlock)
-                while editCursor.position()<screenCursor.selectionEnd() or \
-                        editCursor.position()<=screenCursor.selectionStart():
+                while (
+                    editCursor.position() < screenCursor.selectionEnd()
+                    or editCursor.position() <= screenCursor.selectionStart()
+                ):
                     editCursor.movePosition(editCursor.StartOfBlock)
-                    editCursor.movePosition(editCursor.EndOfBlock, editCursor.KeepAnchor)
+                    editCursor.movePosition(
+                        editCursor.EndOfBlock, editCursor.KeepAnchor
+                    )
                     text1 = editCursor.selectedText()
                     text2 = text1.rstrip()
                     if len(text1) != len(text2):
@@ -536,28 +535,22 @@ class PyzoEditor(BaseTextCtrl):
                 self.setTextCursor(oricursor)
                 editCursor.endEditBlock()
 
-        # Get text and remember where we are
+        # Get text and convert line endings
         text = self.toPlainText()
-        cursor = self.textCursor()
-        linenr = cursor.blockNumber() + 1
-        index = cursor.positionInBlock()
-        scroll = self.verticalScrollBar().value()
-
-        # Convert line endings
-        text = text.replace('\n', self.lineEndings)
+        text = text.replace("\n", self.lineEndings)
 
         # Make bytes
         bb = text.encode(self.encoding)
 
         # Store
-        f = open(filename, 'wb')
+        f = open(filename, "wb")
         try:
             f.write(bb)
         finally:
             f.close()
 
         # Update stats
-        self._filename = normalizePath( filename )
+        self._filename = normalizePath(filename)
         self._name = os.path.split(self._filename)[1]
         self.document().setModified(False)
         self._modifyTime = os.path.getmtime(self._filename)
@@ -566,8 +559,7 @@ class PyzoEditor(BaseTextCtrl):
         self.setTitleInMainWindow()
 
         # allow item to update its texts (no need: onModifiedChanged does this)
-        #self.somethingChanged.emit()
-
+        # self.somethingChanged.emit()
 
     def reload(self):
         """ Reload text using the self._filename.
@@ -586,14 +578,14 @@ class PyzoEditor(BaseTextCtrl):
         linenr = cursor.blockNumber() + 1
 
         # Load file (as bytes)
-        with open(filename, 'rb') as f:
+        with open(filename, "rb") as f:
             bb = f.read()
 
         # Convert to text
-        text = bb.decode('UTF-8')
+        text = bb.decode("UTF-8")
 
         # Process line endings (before setting the text)
-        self.lineEndings= determineLineEnding(text)
+        self.lineEndings = determineLineEnding(text)
 
         # Set text
         self.setPlainText(text)
@@ -636,7 +628,7 @@ class PyzoEditor(BaseTextCtrl):
         Comment the lines that are currently selected
         """
         indents = []
-        indentChar = ' ' if self.indentUsingSpaces() else '\t'
+        indentChar = " " if self.indentUsingSpaces() else "\t"
 
         def getIndent(cursor):
             text = cursor.block().text().rstrip()
@@ -645,45 +637,45 @@ class PyzoEditor(BaseTextCtrl):
 
         def commentBlock(cursor):
             blockText = cursor.block().text()
-            numMissingIndentChars = (minindent -
-                (len(blockText) - len(blockText.lstrip(indentChar))))
+            numMissingIndentChars = minindent - (
+                len(blockText) - len(blockText.lstrip(indentChar))
+            )
             if numMissingIndentChars > 0:
                 # Prevent setPosition from leaving bounds of the current block
                 # if there are too few indent characters (e.g. an empty line)
                 cursor.insertText(indentChar * numMissingIndentChars)
             cursor.setPosition(cursor.block().position() + minindent)
-            cursor.insertText('# ')
+            cursor.insertText("# ")
 
         self.doForSelectedBlocks(getIndent)
         minindent = min(indents) if indents else 0
         self.doForSelectedBlocks(commentBlock)
 
-
     def uncommentCode(self):
         """
         Uncomment the lines that are currently selected
         """
-        #TODO: this should not be applied to lines that are part of a multi-line string
+        # TODO: this should not be applied to lines that are part of a multi-line string
 
-        #Define the uncomment function to be applied to all blocks
+        # Define the uncomment function to be applied to all blocks
         def uncommentBlock(cursor):
             """
             Find the first # on the line; if there is just whitespace before it,
             remove the # and if it is followed by a space remove the space, too
             """
             text = cursor.block().text()
-            commentStart = text.find('#')
+            commentStart = text.find("#")
             if commentStart == -1:
-                return #No comment on this line
-            if text[:commentStart].strip() != '':
-                return #Text before the #
-            #Move the cursor to the beginning of the comment
+                return  # No comment on this line
+            if text[:commentStart].strip() != "":
+                return  # Text before the #
+            # Move the cursor to the beginning of the comment
             cursor.setPosition(cursor.block().position() + commentStart)
             cursor.deleteChar()
-            if text[commentStart:].startswith('# '):
+            if text[commentStart:].startswith("# "):
                 cursor.deleteChar()
 
-        #Apply this function to all blocks
+        # Apply this function to all blocks
         self.doForSelectedBlocks(uncommentBlock)
 
     def gotoDef(self):
@@ -701,10 +693,9 @@ class PyzoEditor(BaseTextCtrl):
         s = pyzo.shells.getCurrentShell()
         if s is not None:
             if word and word.isidentifier():
-                s.executeCommand('open %s\n'%word)
+                s.executeCommand("open %s\n" % word)
             else:
-                s.write('Invalid identifier %r\n' % word)
-
+                s.write("Invalid identifier %r\n" % word)
 
     ## Introspection processing methods
 
@@ -726,7 +717,6 @@ class PyzoEditor(BaseTextCtrl):
             if shell:
                 shell.processCallTip(cto)
 
-
     def processAutoComp(self, aco):
         """ Processes an autocomp request using an AutoCompObject instance.
         """
@@ -761,10 +751,11 @@ class PyzoEditor(BaseTextCtrl):
                 if handleSelf or (className in fictiveNS):
                     # Only the self list (only first iter)
                     fictiveClass = pyzo.parser.getFictiveClass(
-                        className, self, handleSelf)
+                        className, self, handleSelf
+                    )
                     handleSelf = False
                     if fictiveClass:
-                        aco.addNames( fictiveClass.members )
+                        aco.addNames(fictiveClass.members)
                         classNames.extend(fictiveClass.supers)
                 else:
                     nameForShell = className
@@ -773,19 +764,20 @@ class PyzoEditor(BaseTextCtrl):
         # If there's a shell, let it finish the autocompletion
         shell = pyzo.shells.getCurrentShell()
         if shell:
-            aco.name = nameForShell # might be the same or a base class
+            aco.name = nameForShell  # might be the same or a base class
             shell.processAutoComp(aco)
         else:
             # Otherwise we finish it ourselves
             aco.finish()
 
 
-if __name__=="__main__":
+if __name__ == "__main__":
     # Do some stubbing to run this module as a unit separate from pyzo
     # TODO: untangle pyzo from this module where possible
     class DummyParser:
         def parseThis(self, x):
             pass
+
     pyzo.parser = DummyParser()
     EditorContextMenu = QtWidgets.QMenu  # noqa
     app = QtWidgets.QApplication([])
@@ -793,14 +785,14 @@ if __name__=="__main__":
     QtWidgets.QShortcut(QtGui.QKeySequence("Ctrl+C"), win).activated.connect(win.copy)
     QtWidgets.QShortcut(QtGui.QKeySequence("Ctrl+X"), win).activated.connect(win.cut)
     QtWidgets.QShortcut(QtGui.QKeySequence("Ctrl+V"), win).activated.connect(win.paste)
-    QtWidgets.QShortcut(QtGui.QKeySequence("Ctrl+Shift+V"), win).activated.connect(win.pasteAndSelect)
+    QtWidgets.QShortcut(QtGui.QKeySequence("Ctrl+Shift+V"), win).activated.connect(
+        win.pasteAndSelect
+    )
     QtWidgets.QShortcut(QtGui.QKeySequence("Ctrl+Z"), win).activated.connect(win.undo)
     QtWidgets.QShortcut(QtGui.QKeySequence("Ctrl+Y"), win).activated.connect(win.redo)
 
-
     tmp = "foo(bar)\nfor bar in range(5):\n  print bar\n"
     tmp += "\nclass aap:\n  def monkey(self):\n    pass\n\n"
     win.setPlainText(tmp)
     win.show()
     app.exec_()
-
